Registre | OiRA

Temes

# Registre

## Per què m’he de registrar?

El primer que se us demanarà quan comenceu la primera avaluació de riscos és que creeu un compte OiRA; es tracta d’un procés senzill i ràpid.

Registrar-vos us permetrà iniciar sessió en qualsevol moment per accedir a les vostres dades, continuar amb avaluacions anteriors o iniciar avaluacions noves.

Mitjançant el registre, el sistema OiRA desa totes les vostres sessions i sempre tindrà les vostres dades disponibles.

Accediu aquí per obtenir informació addicional sobre com tractem les dades personals.

## Quina és la diferència entre un usuari registrat i una sessió de prova?

Una sessió de prova està pensada perquè les persones interessades examinin l’eina abans de registrar-s’hi. No obstant això, en una sessió de prova les dades no es desen i més endavant no podreu recuperar cap informació introduïda. A més, una sessió de prova no us permet imprimir cap dels informes, mentre que, si us registreu, podreu documentar la vostra avaluació de riscos.

## Registreu un compte nou

És la vostra primera visita? Per començar, seguiu aquests passos senzills:

1) Feu clic a «Registreu-vos» per veure el formulari de registre.

Formulari de registre

2) Introduïu la vostra adreça de correu electrònic i escolliu una contrasenya (l’heu d’introduir dues vegades).

3) Feu clic a «Següent» per registrar el compte nou.

4) Llegiu i accepteu la política de privacitat per continuar.

S’iniciarà sessió directament al sistema OiRA.

## Inicieu sessió en un compte existent

Si ja us heu registrat, podeu accedir al compte d’aquesta manera.

1) Entreu al formulari d’inici de sessió. Se us mostrarà un enllaç al formulari d’inici de sessió cada vegada que intenteu accedir a OiRA, fins que hàgiu iniciat la sessió.

Formulari d’inici de sessió

2) Introduïu l’adreça de correu electrònic i la contrasenya.

3) Inicieu sessió fent clic en el botó «Inicieu sessió».

Un cop que hàgiu iniciat la sessió, veureu la pantalla que es mostra a continuació. Des d’aquí es pot iniciar una nova avaluació de riscos o accedir a avaluacions de riscos ja iniciades.

Tauler de control

Inicieu una nova avaluació de riscos assignant-li un títol (per exemple, Lamevaempresa 2020-07-03) o accediu a una de les vostres avaluacions de riscos anteriors. Totes les avaluacions de riscos es desen, llevat que les elimineu.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More